pub struct Entity {Show 15 fields
pub id: EntityId,
pub max_hp: u64,
pub hp: u64,
pub abilities: Vec<ActiveAbility>,
pub actions_queue: EntityActionsQueue,
pub attributes: EntityAttributes,
pub effect_ids: Vec<EffectId>,
pub coordinates: Coordinates,
pub being_moved: bool,
pub width: i8,
pub rewards: Option<Vec<EnemyReward>>,
pub class_id: Option<ClassId>,
pub team: EntityTeam,
pub has_big_hp_bar: bool,
pub entity_template_id: Option<EntityTemplateId>,
}Fields
id: EntityIdmax_hp: u64hp: u64abilities: Vec<ActiveAbility>actions_queue: EntityActionsQueueattributes: EntityAttributeseffect_ids: Vec<EffectId>coordinates: Coordinatesbeing_moved: boolwidth: i8rewards: Option<Vec<EnemyReward>>class_id: Option<ClassId>team: EntityTeamhas_big_hp_bar: boolentity_template_id: Option<EntityTemplateId>Trait Implementations
Sourceimpl CustomType for Entity
impl CustomType for Entity
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for Entity
impl<'de> Deserialize<'de> for Entity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromWasmAbi for Entitywhere
Self: DeserializeOwned,
impl FromWasmAbi for Entitywhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for Entity
impl IntoWasmAbi for Entity
Sourceimpl JsonSchema for Entity
impl JsonSchema for Entity
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for Entitywhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for Entitywhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for Entity
impl OptionIntoWasmAbi for Entity
Sourceimpl RefFromWasmAbi for Entitywhere
Self: DeserializeOwned,
impl RefFromWasmAbi for Entitywhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourceimpl Tsify for Entity
impl Tsify for Entity
const DECL: &'static str = "export interface Entity {\n id: EntityId;\n max_hp: number;\n hp: number;\n abilities: ActiveAbility[];\n actions_queue: EntityActionsQueue;\n attributes: EntityAttributes;\n effect_ids: EffectId[];\n coordinates: Coordinates;\n being_moved: boolean;\n width: number;\n rewards: EnemyReward[] | null;\n class_id: ClassId | null;\n team: EntityTeam;\n has_big_hp_bar: boolean;\n entity_template_id: EntityTemplateId | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for Entitywhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for Entitywhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for Entity
impl VectorIntoWasmAbi for Entity
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
impl Eq for Entity
impl StructuralPartialEq for Entity